<?php

namespace Litecms\Buyadetails\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Buyadetails\Http\Requests\BuyadetailsRequest;
use Litecms\Buyadetails\Interfaces\BuyadetailsRepositoryInterface;
use Litecms\Buyadetails\Models\Buyadetails;

/**
 * Resource controller class for buyadetails.
 */
class BuyadetailsResourceController extends BaseController
{

    /**
     * Initialize buyadetails resource controller.
     *
     * @param type BuyadetailsRepositoryInterface $buyadetails
     *
     * @return null
     */
    public function __construct(BuyadetailsRepositoryInterface $buyadetails)
    {
        parent::__construct();
        $this->repository = $buyadetails;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Buyadetails\Repositories\Criteria\BuyadetailsResourceCriteria::class);
    }

    /**
     * Display a list of buyadetails.
     *
     * @return Response
     */
    public function index(BuyadetailsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Buyadetails\Repositories\Presenter\BuyadetailsPresenter::class)
                ->$function();
        }

        $buyadetails = $this->repository->paginate();

        return $this->response->title(trans('buyadetails::buyadetails.names'))
            ->view('buyadetails::buyadetails.index', true)
            ->data(compact('buyadetails'))
            ->output();
    }

    /**
     * Display buyadetails.
     *
     * @param Request $request
     * @param Model   $buyadetails
     *
     * @return Response
     */
    public function show(BuyadetailsRequest $request, Buyadetails $buyadetails)
    {

        if ($buyadetails->exists) {
            $view = 'buyadetails::buyadetails.show';
        } else {
            $view = 'buyadetails::buyadetails.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('buyadetails::buyadetails.name'))
            ->data(compact('buyadetails'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new buyadetails.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BuyadetailsRequest $request)
    {

        $buyadetails = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('buyadetails::buyadetails.name')) 
            ->view('buyadetails::buyadetails.create', true) 
            ->data(compact('buyadetails'))
            ->output();
    }

    /**
     * Create new buyadetails.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BuyadetailsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $buyadetails                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('buyadetails::buyadetails.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('buyadetails/buyadetails/' . $buyadetails->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/buyadetails/buyadetails'))
                ->redirect();
        }

    }

    /**
     * Show buyadetails for editing.
     *
     * @param Request $request
     * @param Model   $buyadetails
     *
     * @return Response
     */
    public function edit(BuyadetailsRequest $request, Buyadetails $buyadetails)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('buyadetails::buyadetails.name'))
            ->view('buyadetails::buyadetails.edit', true)
            ->data(compact('buyadetails'))
            ->output();
    }

    /**
     * Update the buyadetails.
     *
     * @param Request $request
     * @param Model   $buyadetails
     *
     * @return Response
     */
    public function update(BuyadetailsRequest $request, Buyadetails $buyadetails)
    {
        try {
            $attributes = $request->all();

            $buyadetails->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('buyadetails::buyadetails.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('buyadetails/buyadetails/' . $buyadetails->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('buyadetails/buyadetails/' . $buyadetails->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the buyadetails.
     *
     * @param Model   $buyadetails
     *
     * @return Response
     */
    public function destroy(BuyadetailsRequest $request, Buyadetails $buyadetails)
    {
        try {

            $buyadetails->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('buyadetails::buyadetails.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('buyadetails/buyadetails/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('buyadetails/buyadetails/' . $buyadetails->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple buyadetails.
     *
     * @param Model   $buyadetails
     *
     * @return Response
     */
    public function delete(BuyadetailsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('buyadetails::buyadetails.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('buyadetails/buyadetails'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/buyadetails/buyadetails'))
                ->redirect();
        }

    }

    /**
     * Restore deleted buyadetails.
     *
     * @param Model   $buyadetails
     *
     * @return Response
     */
    public function restore(BuyadetailsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('buyadetails::buyadetails.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/buyadetails/buyadetails'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/buyadetails/buyadetails/'))
                ->redirect();
        }

    }

}
